package com.nisum.banderson;

import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.openqa.selenium.Platform;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.chrome.ChromeDriver;
import org.openqa.selenium.remote.RemoteWebDriver;
import org.openqa.selenium.safari.SafariDriver;
import org.openqa.selenium.support.PageFactory;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.WebDriverWait;

import java.util.concurrent.TimeUnit;

public class Test {
    private static WebDriver driver;
    private static String url;


    @BeforeEach
    public void setUp() {
        url = "http://www.albertsons.com";
        switch (PropertyManager.getInstance().getBrowser()) {
            case "chrome":
                driver = new ChromeDriver();
                break;

            case "safari":
                driver = new SafariDriver();
                break;
        }

        driver.manage().timeouts().implicitlyWait(3000, TimeUnit.MILLISECONDS);
        Platform platform = ((RemoteWebDriver) driver).getCapabilities().getPlatform();
        System.out.printf(
                "Running WebDriver on %s browser running on %s platform...", PropertyManager.getInstance().getBrowser(), platform
        );
        driver.manage().window().maximize();
        driver.navigate().to(url);
    }

    @AfterEach
    public void tearDown() {
        driver.close();
    }


    @org.junit.jupiter.api.Test
    public void login() throws Exception {
        Login login = new Login(driver);
        Header header = new Header(driver);

        login.login();

        Assertions.assertEquals("Account", header.getOpenSidebarButton().getText());
    }


    @org.junit.jupiter.api.Test
    public void testNavigation() {
        AccountPage accountPage = new AccountPage(driver);
        accountPage.navigateTo();
        Assertions.assertEquals("Account Settings | albertsons", driver.getTitle());
    }

    @org.junit.jupiter.api.Test
    public void confirmAccountDetails() throws InterruptedException {
        AccountPage accountPage = new AccountPage(driver);
        PageFactory.initElements(driver, accountPage);

        accountPage.navigateTo();

        new WebDriverWait(driver, 20)
                .until(ExpectedConditions.titleIs("Account Settings | albertsons"));

        Thread.sleep(3000);

        Assertions.assertAll(
                () -> Assertions.assertEquals(
                        PropertyManager.getInstance().getFirstName(),
                        accountPage.firstNameInput.getAttribute("value")
                ), () -> Assertions.assertEquals(
                        PropertyManager.getInstance().getLastName(),
                        accountPage.lastNameInput.getAttribute("value")
                ), () -> Assertions.assertEquals(
                        PropertyManager.getInstance().getEmail(),
                        accountPage.emailInput.getAttribute("value")
                )
        );
    }
}
